==> spip_3.0.18.orig.tar.xz: spip/ecrire/lang/public_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Главная',
	'article' => 'Статья',
	'articles' => 'Статьи',
	'articles_auteur' => 'Статьи автора',
	'articles_populaires' => 'Самые читаемые статьи',
	'articles_rubrique' => 'Статьи в этом разделе',
	'aucun_article' => 'Статей нет',
	'aucun_auteur' => 'Авторов нет',
	'aucun_site' => 'Сайтов нет',
	'aucune_breve' => 'Новостей нет',
	'aucune_rubrique' => 'Разделов нет',
	'auteur' => 'Автор',
	'autres' => 'Прочие',
	'autres_breves' => 'Другие новости',
	'autres_groupes_mots_clefs' => 'Другие группы ключей',
	'autres_sites' => 'Другие сайты',

	// B
	'bonjour' => 'Привет',

	// C
	'commenter_site' => 'Коментарии к этому сайту',
	'contact' => 'Контакты',
	'copie_document_impossible' => 'Невозможно скопировать документ',

	// D
	'date' => 'Дата',
	'dernier_ajout' => 'Последнее обновление',
	'dernieres_breves' => 'Свежие новости',
	'derniers_articles' => 'Новые статьи',
	'derniers_commentaires' => 'Новые комментарии',
	'derniers_messages_forum' => 'Новые сообщения на форуме',

	// E
	'edition_mode_texte' => 'Текстовый режим',
	'en_reponse' => 'Комментарий к:',
	'en_resume' => 'Резюме',
	'envoyer_message' => 'Отправить сообщение',
	'espace_prive' => 'Административная часть',

	// F
	'formats_acceptes' => 'Допустимые форматы: @formats@.',

	// H
	'hierarchie_site' => 'Карта сайта',

	// J
	'jours' => 'дни',

	// L
	'lien_connecter' => 'Войти',

	// M
	'meme_auteur' => 'Этого автора',
	'meme_rubrique' => 'Еще в разделе',
	'memes_auteurs' => 'Теми же авторами',
	'message' => 'Сообщение',
	'messages_forum' => 'Сообщения форума',
	'messages_recents' => 'Новые сообщения форума',
	'mots_clef' => 'Ключ',
	'mots_clefs' => 'Ключи',
	'mots_clefs_meme_groupe' => 'Ключи из этой группы',

	// N
	'navigation' => 'Просмотр',
	'nom' => 'Имя',
	'nouveautes' => 'Что нового',
	'nouveautes_web' => 'Что нового в сайтах',
	'nouveaux_articles' => 'Новые статьи',
	'nouvelles_breves' => 'Свежие новости',

	// P
	'page_precedente' => 'предыдущая страница',
	'page_suivante' => 'следующая страница',
	'par_auteur' => ' ',
	'participer_site' => 'Вы можете принять активное участие в жизни этого сайта и писать ваши собственные статьи. Все, что надо сделать - зарегистрироваться.',
	'plan_site' => 'Карта сайта',
	'popularite' => 'Популярность',
	'poster_message' => 'Отправить сообщение',
	'proposer_site' => 'Вы можете добавить ссылку на сайт в этот раздел:',

	// R
	'repondre_article' => 'Оставить комментарий ',
	'repondre_breve' => 'Оставить комментарий ',
	'resultats_recherche' => 'Результаты поиска',
	'retour_debut_forums' => 'Все форумы',
	'rubrique' => 'Раздел',
	'rubriques' => 'Разделы',

	// S
	'signatures_petition' => 'Подписи',
	'site_realise_avec_spip' => 'Сайт работает на SPIP',
	'sites_web' => 'Сайты',
	'sous_rubriques' => 'Подразделы',
	'spam' => 'Спам',
	'suite' => 'продолжить',
	'sur_web' => 'В интернете',
	'syndiquer_rubrique' => 'RSS этого раздела',
	'syndiquer_site' => 'RSS всего сайта',

	// T
	'texte_lettre_information' => 'Информационный бюллетень сайта',
	'texte_lettre_information_2' => 'Материалы на сайте размещаются с',

	// V
	'ver_imprimer' => 'Версия для печати',
	'voir_en_ligne' => 'См. онлайн',
	'voir_squelette' => 'показать шаблон этой страницы'
);

?>

==> spip_3.1.0.orig.tar.xz: spip/ecrire/lang/public_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Главная',
	'article' => 'Статья',
	'articles' => 'Статьи',
	'articles_auteur' => 'Статьи автора',
	'articles_populaires' => 'Самые читаемые статьи',
	'articles_rubrique' => 'Статьи в этом разделе',
	'aucun_article' => 'Статей нет',
	'aucun_auteur' => 'Авторов нет',
	'aucun_site' => 'Сайтов нет',
	'aucune_breve' => 'Новостей нет',
	'aucune_rubrique' => 'Разделов нет',
	'auteur' => 'Автор',
	'autres' => 'Прочие',
	'autres_breves' => 'Другие новости',
	'autres_groupes_mots_clefs' => 'Другие группы ключей',
	'autres_sites' => 'Другие сайты',

	// B
	'bonjour' => 'Привет',

	// C
	'commenter_site' => 'Комментарии к этому сайту',
	'contact' => 'Контакты',
	'copie_document_impossible' => 'Невозможно скопировать документ',

	// D
	'date' => 'Дата',
	'dernier_ajout' => 'Последнее обновление',
	'dernieres_breves' => 'Свежие новости',
	'derniers_articles' => 'Новые статьи',
	'derniers_commentaires' => 'Новые комментарии',
	'derniers_messages_forum' => 'Новые сообщения на форуме',

	// E
	'edition_mode_texte' => 'Текстовый режим',
	'en_reponse' => 'Комментарий к:',
	'en_resume' => 'Резюме',
	'envoyer_message' => 'Отправить сообщение',
	'espace_prive' => 'Административная часть',

	// F
	'formats_acceptes' => 'Допустимые форматы: @formats@.',

	// H
	'hierarchie_site' => 'Карта сайта',

	// J
	'jours' => 'дни',

	// L
	'lien_connecter' => 'Войти',

	// M
	'meme_auteur' => 'Этого автора',
	'meme_rubrique' => 'Еще в разделе',
	'memes_auteurs' => 'Теми же авторами',
	'message' => 'Сообщение',
	'messages_forum' => 'Сообщения форума',
	'messages_recents' => 'Новые сообщения форума',
	'mots_clef' => 'Ключ',
	'mots_clefs' => 'Ключи',
	'mots_clefs_meme_groupe' => 'Ключи из этой группы',

	// N
	'navigation' => 'Просмотр',
	'nom' => 'Имя',
	'nouveautes' => 'Что нового',
	'nouveautes_web' => 'Что нового в сайтах',
	'nouveaux_articles' => 'Новые статьи',
	'nouvelles_breves' => 'Свежие новости',

	// P
	'page_precedente' => 'предыдущая страница',
	'page_suivante' => 'следующая страница',
	'par_auteur' => ' ',
	'participer_site' => 'Вы можете принять активное участие в жизни этого сайта и писать ваши собственные статьи. Все, что надо сделать, - зарегистрироваться.',
	'plan_site' => 'Карта сайта',
	'popularite' => 'Популярность',
	'poster_message' => 'Отправить сообщение',
	'proposer_site' => 'Вы можете добавить ссылку на сайт в этот раздел:',

	// R
	'repondre_article' => 'Оставить комментарий ',
	'repondre_breve' => 'Оставить комментарий ',
	'resultats_recherche' => 'Результаты поиска',
	'retour_debut_forums' => 'Все форумы',
	'rubrique' => 'Раздел',
	'rubriques' => 'Разделы',

	// S
	'signatures_petition' => 'Подписи',
	'site_realise_avec_spip' => 'Сайт работает на SPIP',
	'sites_web' => 'Сайты',
	'sous_rubriques' => 'Подразделы',
	'spam' => 'Спам',
	'suite' => 'продолжить',
	'sur_web' => 'В интернете',
	'syndiquer_rubrique' => 'RSS этого раздела',
	'syndiquer_site' => 'RSS всего сайта',

	// T
	'texte_lettre_information' => 'Информационный бюллетень сайта',
	'texte_lettre_information_2' => 'Материалы на сайте размещаются с',

	// V
	'ver_imprimer' => 'Версия для печати',
	'voir_en_ligne' => 'См. онлайн',
	'voir_squelette' => 'показать шаблон этой страницы'
);

?>
